@@ -135,7 +135,6 @@ ecmm_value_at (ETableModel *etm, gint col, gint row)
 	return (gpointer) "";
 }
 
-
 static void
 ecmm_set_value_at (ETableModel *etm, gint col, gint row, gconstpointer value)
 {
@@ -152,7 +151,7 @@ ecmm_set_value_at (ETableModel *etm, gint col, gint row, gconstpointer value)
 	}
 
 	comp_data = e_cal_model_get_component_at (E_CAL_MODEL (model), row);
-	if (!comp_data){
+	if (!comp_data) {
 		g_warning("couldn't get component data: row == %d", row);
 		return;
 	}
@@ -261,8 +260,12 @@ ecmm_fill_component_from_model (ECalModel *model, ECalModelComponent *comp_data,
 /**
  * e_cal_model_memos_new
  */
-ECalModelMemos *
-e_cal_model_memos_new (void)
+ECalModel *
+e_cal_model_memos_new (EShellSettings *shell_settings)
 {
-	return g_object_new (E_TYPE_CAL_MODEL_MEMOS, NULL);
+	g_return_val_if_fail (E_IS_SHELL_SETTINGS (shell_settings), NULL);
+
+	return g_object_new (
+		E_TYPE_CAL_MODEL_MEMOS,
+		"shell-settings", shell_settings, NULL);
 }
