@@ -87,7 +87,6 @@ enum {
 	OPEN_COMPONENT,
 	POPUP_EVENT,
 	STATUS_MESSAGE,
-	USER_CREATED,
 	LAST_SIGNAL
 };
 
@@ -132,14 +131,6 @@ task_table_emit_status_message (ETaskTable *task_table,
 	g_signal_emit (task_table, signal_id, 0, message, percent);
 }
 
-static void
-task_table_emit_user_created (ETaskTable *task_table)
-{
-	guint signal_id = signals[USER_CREATED];
-
-	g_signal_emit (task_table, signal_id, 0);
-}
-
 static gint
 task_table_percent_compare_cb (gconstpointer a, gconstpointer b, gpointer cmp_cache)
 {
@@ -296,10 +287,6 @@ task_table_set_model (ETaskTable *task_table,
 
 	task_table->priv->model = g_object_ref (model);
 
-	g_signal_connect_swapped (
-		model, "row_appended",
-		G_CALLBACK (task_table_emit_user_created), task_table);
-
 	g_signal_connect_swapped (
 		model, "cal-view-progress",
 		G_CALLBACK (task_table_model_cal_view_progress_cb),
@@ -1409,15 +1396,6 @@ task_table_class_init (ETaskTableClass *class)
 		e_marshal_VOID__STRING_DOUBLE,
 		G_TYPE_NONE, 2,
 		G_TYPE_STRING, G_TYPE_DOUBLE);
-
-	signals[USER_CREATED] = g_signal_new (
-		"user-created",
-		G_TYPE_FROM_CLASS (class),
-		G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		G_STRUCT_OFFSET (ETaskTableClass, user_created),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
-		G_TYPE_NONE, 0);
 }
 
 static void
@@ -1620,7 +1598,7 @@ hide_completed_rows (ECalModel *model,
 				changed = TRUE;
 
 				if (g_ptr_array_remove (comp_objects, comp_data))
-					e_cal_model_free_component_data (comp_data);
+					g_object_unref (comp_data);
 			}
 			e_cal_component_free_id (id);
 			g_object_unref (comp);
