@@ -22,7 +22,7 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
-#include <e-util/e-error.h>
+#include <e-util/e-alert-dialog.h>
 #include <e-util/e-util.h>
 #include <camel/camel-stream-fs.h>
 #include <camel/camel-stream-mem.h>
@@ -91,6 +91,7 @@ static gboolean
 composer_autosave_state_open (AutosaveState *state)
 {
 	gchar *path;
+	gint fd;
 
 	if (state->file != NULL)
 		return TRUE;
@@ -100,13 +101,16 @@ composer_autosave_state_open (AutosaveState *state)
 
 	/* Since GIO doesn't have support for creating temporary files
 	 * from a template (and in a given directory), we have to use
-	 * mktemp(), which brings a small risk of overwriting another
+	 * g_mkstemp(), which brings a small risk of overwriting another
 	 * autosave file.  The risk is, however, miniscule. */
-	if (mktemp (path) == NULL) {
+	fd = g_mkstemp (path);
+	if (fd == -1) {
 		g_free (path);
 		return FALSE;
 	}
 
+	close (fd);
+
 	/* Create the GFile */
 	state->file = g_file_new_for_path (path);
 	g_free (path);
@@ -123,7 +127,7 @@ composer_autosave_finish_cb (EMsgComposer *composer,
 	e_composer_autosave_snapshot_finish (composer, result, &error);
 
 	if (error != NULL) {
-		e_error_run (
+		e_alert_run_dialog_for_args (
 			GTK_WINDOW (composer),
 			"mail-composer:no-autosave",
 			"", error->message, NULL);
