@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -21,36 +21,49 @@
  *
  */
 
-#ifndef __E_CONFIG_H__
-#define __E_CONFIG_H__
+#ifndef E_CONFIG_H
+#define E_CONFIG_H
 
-#include <glib-object.h>
-#include "libedataserver/e-msgport.h"
+#include <gtk/gtk.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+/* Standard GObject macros */
+#define E_TYPE_CONFIG \
+	(e_config_get_type ())
+#define E_CONFIG(obj) \
+	(G_TYPE_CHECK_INSTANCE_CAST \
+	((obj), E_TYPE_CONFIG, EConfig))
+#define E_CONFIG_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_CAST \
+	((cls), E_TYPE_CONFIG, EConfigClass))
+#define E_IS_CONFIG(obj) \
+	(G_TYPE_CHECK_INSTANCE_TYPE \
+	((obj), E_TYPE_CONFIG))
+#define E_IS_CONFIG_CLASS(cls) \
+	(G_TYPE_CHECK_CLASS_TYPE \
+	((cls), E_TYPE_CONFIG))
+#define E_CONFIG_GET_CLASS(obj) \
+	(G_TYPE_INSTANCE_GET_CLASS \
+	((obj), E_TYPE_CONFIG, EConfigClass))
 
-struct _GtkWindow;
-struct _GtkWidget;
+G_BEGIN_DECLS
 
 /* This is a config window management/merging class. */
 
 typedef struct _EConfig EConfig;
 typedef struct _EConfigClass EConfigClass;
+typedef struct _EConfigPrivate EConfigPrivate;
 
 typedef struct _EConfigItem EConfigItem;
 typedef struct _EConfigFactory EConfigFactory;
 typedef struct _EConfigTarget EConfigTarget;
 
-typedef void (*EConfigFactoryFunc)(EConfig *ec, void *data);
+typedef void (*EConfigFactoryFunc)(EConfig *ec, gpointer data);
 
-typedef gboolean (*EConfigCheckFunc)(EConfig *ec, const char *pageid, void *data);
+typedef gboolean (*EConfigCheckFunc)(EConfig *ec, const gchar *pageid, gpointer data);
 
-typedef void (*EConfigItemsFunc)(EConfig *ec, GSList *items, void *data);
+typedef void (*EConfigItemsFunc)(EConfig *ec, GSList *items, gpointer data);
 
-typedef struct _GtkWidget * (*EConfigItemFactoryFunc)(EConfig *ec, EConfigItem *, struct _GtkWidget *parent, struct _GtkWidget *old, void *data);
+typedef GtkWidget * (*EConfigItemFactoryFunc)(EConfig *ec, EConfigItem *, GtkWidget *parent, GtkWidget *old, gpointer data);
 
 /* ok so this is all a bit bogussy
    we need to map to glade stuff instead */
@@ -82,18 +95,18 @@ enum _e_config_target_change_t {
  * enum _e_config_t - configuration item type.
  *
  * @E_CONFIG_BOOK: A notebook item.  Only one of this or
- * @E_CONFIG_DRUID may be included in the item list for the entire
+ * @E_CONFIG_ASSISTANT may be included in the item list for the entire
  * configuration description.
- * @E_CONFIG_DRUID: A druid item.  Only one of this or @E_CONFIG_BOOK
+ * @E_CONFIG_ASSISTANT: An assistant item.  Only one of this or @E_CONFIG_BOOK
  * may be included in the item list for the entire configutation
  * description.
  * @E_CONFIG_PAGE: A configuration page.  The item @label will be
- * either the notebook tab label or the druid page title if no factory
+ * either the notebook tab label or the assistant page title if no factory
  * is supplied.
- * @E_CONFIG_PAGE_START: A druid start page.  Only one of these may be
- * supplied for a druid and it should be the first page in the druid.
- * @E_CONFIG_PAGE_FINISH: A druid finish page.  Only one of these may
- * be supplied for a druid and it should be the last page of the druid.
+ * @E_CONFIG_PAGE_START: An assistant start page.  Only one of these may be
+ * supplied for a assistant and it should be the first page in the assistant.
+ * @E_CONFIG_PAGE_FINISH: An assistant finish page.  Only one of these may
+ * be supplied for an assistant and it should be the last page of the assistant.
  * @E_CONFIG_SECTION: A section in the configuration page.  A page for
  * this section must have already been defined.  The item @label if
  * supplied will be setup as a borderless hig-compliant frame title.
@@ -115,11 +128,11 @@ enum _e_config_target_change_t {
 enum _e_config_t {
 	/* use one and only one of these for any given config-window id */
 	E_CONFIG_BOOK,
-	E_CONFIG_DRUID,
+	E_CONFIG_ASSISTANT,
 
 	E_CONFIG_PAGE,
-	E_CONFIG_PAGE_START,	/* only allowed in druid types */
-	E_CONFIG_PAGE_FINISH,	/* only allowed in druid types */
+	E_CONFIG_PAGE_START,	/* only allowed in assistant types */
+	E_CONFIG_PAGE_FINISH,	/* only allowed in assistant types */
 	E_CONFIG_SECTION,
 	E_CONFIG_SECTION_TABLE,
 	E_CONFIG_ITEM,
@@ -144,10 +157,10 @@ enum _e_config_t {
  **/
 struct _EConfigItem {
 	enum _e_config_t type;
-	char *path;		/* absolute path, must sort ascii-lexographically into the right spot */
-	char *label;
+	gchar *path;		/* absolute path, must sort ascii-lexographically into the right spot */
+	gchar *label;
 	EConfigItemFactoryFunc factory;
-	void *user_data;
+	gpointer user_data;
 };
 
 /**
@@ -164,7 +177,7 @@ struct _EConfigItem {
  **/
 struct _EConfigTarget {
 	struct _EConfig *config;
-	struct _GtkWidget *widget;	/* used if you need a parent toplevel, if available */
+	GtkWidget *widget;	/* used if you need a parent toplevel, if available */
 
 	guint32 type;
 
@@ -181,7 +194,7 @@ struct _EConfigTarget {
  * @id: The globally unique identifider for this configuration window,
  * used for hooking into it.
  * @target: The current target.
- * @widget: The GtkNoteBook or GnomeDruid created after
+ * @widget: The GtkNoteBook or GtkAssistant created after
  * :create_widget() is called that represents the merged and combined
  * configuration window.
  * @window: If :create_window() is called, then the containing
@@ -191,17 +204,16 @@ struct _EConfigTarget {
  **/
 struct _EConfig {
 	GObject object;
+	EConfigPrivate *priv;
 
-	struct _EConfigPrivate *priv;
+	gint type;		/* E_CONFIG_BOOK or E_CONFIG_ASSISTANT */
 
-	int type;		/* E_CONFIG_BOOK or E_CONFIG_DRUID */
-
-	char *id;
+	gchar *id;
 
 	EConfigTarget *target;
 
-	struct _GtkWidget *widget; /* the generated internal */
-	struct _GtkWidget *window; /* the window widget, GtkWindow or GtkDialog */
+	GtkWidget *widget; /* the generated internal */
+	GtkWidget *window; /* the window widget, GtkWindow or GtkDialog */
 };
 
 /**
@@ -220,41 +232,43 @@ struct _EConfig {
 struct _EConfigClass {
 	GObjectClass object_class;
 
-	EDList factories;
+	GList *factories;
 
-	void (*set_target)(EConfig *ep, EConfigTarget *t);
-
-	void (*target_free)(EConfig *ep, EConfigTarget *t);
+	void		(*set_target)		(EConfig *config,
+						 EConfigTarget *target);
+	void		(*target_free)		(EConfig *config,
+						 EConfigTarget *target);
 };
 
 GType e_config_get_type(void);
 
 /* Static class methods */
-EConfigFactory *e_config_class_add_factory(EConfigClass *klass, const char *id, EConfigFactoryFunc func, void *data);
+EConfigFactory *e_config_class_add_factory(EConfigClass *klass, const gchar *id, EConfigFactoryFunc func, gpointer user_data);
 void e_config_class_remove_factory(EConfigClass *klass, EConfigFactory *f);
 
-EConfig *e_config_construct(EConfig *, int type, const char *id);
+EConfig *e_config_construct(EConfig *, gint type, const gchar *id);
 
-void e_config_add_items(EConfig *, GSList *items, EConfigItemsFunc commitfunc, EConfigItemsFunc abortfunc, EConfigItemsFunc freefunc, void *data);
-void e_config_add_page_check(EConfig *, const char *pageid, EConfigCheckFunc, void *data);
+void e_config_add_items(EConfig *, GSList *items, EConfigItemsFunc commitfunc, EConfigItemsFunc abortfunc, EConfigItemsFunc freefunc, gpointer data);
+void e_config_add_page_check(EConfig *, const gchar *pageid, EConfigCheckFunc, gpointer data);
+void e_config_set_page_is_finish (EConfig *ec, const gchar *pageid, gboolean is_finish);
 
 void e_config_set_target(EConfig *emp, EConfigTarget *target);
-struct _GtkWidget *e_config_create_widget(EConfig *);
-struct _GtkWidget *e_config_create_window(EConfig *emp, struct _GtkWindow *parent, const char *title);
+GtkWidget *e_config_create_widget(EConfig *);
+GtkWidget *e_config_create_window(EConfig *emp, GtkWindow *parent, const gchar *title);
 
 void e_config_target_changed(EConfig *emp, e_config_target_change_t how);
 
-gboolean e_config_page_check(EConfig *, const char *);
+gboolean e_config_page_check(EConfig *, const gchar *);
 
-struct _GtkWidget *e_config_page_get(EConfig *ec, const char *pageid);
-const char *e_config_page_next(EConfig *ec, const char *pageid);
-const char *e_config_page_prev(EConfig *ec, const char *pageid);
+GtkWidget *e_config_page_get(EConfig *ec, const gchar *pageid);
+const gchar *e_config_page_next(EConfig *ec, const gchar *pageid);
+const gchar *e_config_page_prev(EConfig *ec, const gchar *pageid);
 
 void e_config_abort(EConfig *);
 void e_config_commit(EConfig *);
 
-void *e_config_target_new(EConfig *, int type, size_t size);
-void e_config_target_free(EConfig *, void *);
+gpointer e_config_target_new(EConfig *, gint type, gsize size);
+void e_config_target_free(EConfig *, gpointer );
 
 /* ********************************************************************** */
 
@@ -298,8 +312,8 @@ struct _EConfigHookItemFactoryData {
 	EConfig *config;
 	EConfigItem *item;
 	EConfigTarget *target;
-	struct _GtkWidget *parent;
-	struct _GtkWidget *old;
+	GtkWidget *parent;
+	GtkWidget *old;
 };
 
 /**
@@ -314,7 +328,7 @@ struct _EConfigHookItemFactoryData {
 struct _EConfigHookPageCheckData {
 	EConfig *config;
 	EConfigTarget *target;
-	const char *pageid;
+	const gchar *pageid;
 };
 
 /**
@@ -336,12 +350,12 @@ struct _EConfigHookPageCheckData {
  **/
 struct _EConfigHookGroup {
 	struct _EConfigHook *hook; /* parent pointer */
-	char *id;		/* target menu id for these config items */
-	int target_type;	/* target type of this group */
+	gchar *id;		/* target menu id for these config items */
+	gint target_type;	/* target type of this group */
 	GSList *items;		/* items to add to group */
-	char *check;		/* validate handler, if set */
-	char *commit;		/* commit handler, if set */
-	char *abort;		/* abort handler, if set */
+	gchar *check;		/* validate handler, if set */
+	gchar *commit;		/* commit handler, if set */
+	gchar *abort;		/* abort handler, if set */
 };
 
 /**
@@ -386,8 +400,6 @@ GType e_config_hook_get_type(void);
 /* for implementors */
 void e_config_hook_class_add_target_map(EConfigHookClass *klass, const EConfigHookTargetMap *);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
-#endif /* __E_CONFIG_H__ */
+#endif /* E_CONFIG_H */
