@@ -560,14 +560,6 @@ action_memo_view_cb (GtkRadioAction *action,
 	gtk_orientable_set_orientation (orientable, orientation);
 }
 
-static void
-action_search_filter_cb (GtkRadioAction *action,
-                         GtkRadioAction *current,
-                         EShellView *shell_view)
-{
-	e_shell_view_execute_search (shell_view);
-}
-
 static GtkActionEntry memo_entries[] = {
 
 	{ "memo-delete",
@@ -892,9 +884,6 @@ e_memo_shell_view_actions_init (EMemoShellView *memo_shell_view)
 	gtk_action_set_visible (action, FALSE);
 	e_shell_searchbar_set_search_option (
 		searchbar, GTK_RADIO_ACTION (action));
-	gtk_radio_action_set_current_value (
-		GTK_RADIO_ACTION (action),
-		MEMO_SEARCH_SUMMARY_CONTAINS);
 
 	/* Lockdown Printing Actions */
 	action_group = ACTION_GROUP (LOCKDOWN_PRINTING);
@@ -967,13 +956,13 @@ e_memo_shell_view_update_search_filter (EMemoShellView *memo_shell_view)
 	action_group = ACTION_GROUP (MEMOS_FILTER);
 	e_action_group_remove_all_actions (action_group);
 
-	/* Add the standard filter actions. */
+	/* Add the standard filter actions.  No callback is needed
+	 * because changes in the EActionComboBox are detected and
+	 * handled by EShellSearchbar. */
 	gtk_action_group_add_radio_actions (
 		action_group, memo_filter_entries,
 		G_N_ELEMENTS (memo_filter_entries),
-		MEMO_FILTER_ANY_CATEGORY,
-		G_CALLBACK (action_search_filter_cb),
-		memo_shell_view);
+		MEMO_FILTER_ANY_CATEGORY, NULL, NULL);
 
 	/* Retrieve the radio group from an action we just added. */
 	list = gtk_action_group_list_actions (action_group);
@@ -1024,12 +1013,17 @@ e_memo_shell_view_update_search_filter (EMemoShellView *memo_shell_view)
 	}
 	g_list_free (list);
 
-	/* Use any action in the group; doesn't matter which. */
 	memo_shell_content = memo_shell_view->priv->memo_shell_content;
 	searchbar = e_memo_shell_content_get_searchbar (memo_shell_content);
 	combo_box = e_shell_searchbar_get_filter_combo_box (searchbar);
+
+	e_shell_view_block_execute_search (shell_view);
+
+	/* Use any action in the group; doesn't matter which. */
 	e_action_combo_box_set_action (combo_box, radio_action);
 
 	ii = MEMO_FILTER_UNMATCHED;
 	e_action_combo_box_add_separator_after (combo_box, ii);
+
+	e_shell_view_unblock_execute_search (shell_view);
 }
