@@ -506,21 +506,6 @@ shell_view_constructed (GObject *object)
 	shell_view->priv->size_group = NULL;
 }
 
-static void
-shell_view_clear_search (EShellView *shell_view)
-{
-	e_shell_view_set_search_rule (shell_view, NULL);
-	e_shell_view_execute_search (shell_view);
-}
-
-static void
-shell_view_custom_search (EShellView *shell_view,
-                          EFilterRule *custom_rule)
-{
-	e_shell_view_set_search_rule (shell_view, custom_rule);
-	e_shell_view_execute_search (shell_view);
-}
-
 static void
 shell_view_toggled (EShellView *shell_view)
 {
@@ -552,6 +537,33 @@ shell_view_toggled (EShellView *shell_view)
 	gtk_ui_manager_ensure_update (ui_manager);
 }
 
+static void
+shell_view_clear_search (EShellView *shell_view)
+{
+	e_shell_view_set_search_rule (shell_view, NULL);
+	e_shell_view_execute_search (shell_view);
+}
+
+static void
+shell_view_custom_search (EShellView *shell_view,
+                          EFilterRule *custom_rule)
+{
+	e_shell_view_set_search_rule (shell_view, custom_rule);
+	e_shell_view_execute_search (shell_view);
+}
+
+static void
+shell_view_update_actions (EShellView *shell_view)
+{
+	EShellWindow *shell_window;
+	EFocusTracker *focus_tracker;
+
+	shell_window = e_shell_view_get_shell_window (shell_view);
+	focus_tracker = e_shell_window_get_focus_tracker (shell_window);
+
+	e_focus_tracker_update_actions (focus_tracker);
+}
+
 static void
 shell_view_class_init (EShellViewClass *class)
 {
@@ -574,9 +586,10 @@ shell_view_class_init (EShellViewClass *class)
 	class->new_shell_sidebar = e_shell_sidebar_new;
 	class->new_shell_taskbar = e_shell_taskbar_new;
 
+	class->toggled = shell_view_toggled;
 	class->clear_search = shell_view_clear_search;
 	class->custom_search = shell_view_custom_search;
-	class->toggled = shell_view_toggled;
+	class->update_actions = shell_view_update_actions;
 
 	/**
 	 * EShellView:action:
@@ -1389,8 +1402,8 @@ e_shell_view_execute_search (EShellView *shell_view)
  * e_shell_view_block_execute_search:
  * @shell_view: an #EShellView
  *
- * Blocks e_shell_view_execute_search in a way it does nothing.
- * Pair function for this is e_shell_view_unblock_execute_search.
+ * Blocks e_shell_view_execute_search() in a way it does nothing.
+ * Pair function for this is e_shell_view_unblock_execute_search().
  **/
 void
 e_shell_view_block_execute_search (EShellView *shell_view)
@@ -1405,8 +1418,8 @@ e_shell_view_block_execute_search (EShellView *shell_view)
  * e_shell_view_unblock_execute_search:
  * @shell_view: an #EShellView
  *
- * Unblocks previously blocked e_shell_view_execute_search with
- * function e_shell_view_block_execute_search.
+ * Unblocks previously blocked e_shell_view_execute_search() with
+ * function e_shell_view_block_execute_search().
  **/
 void
 e_shell_view_unblock_execute_search (EShellView *shell_view)
