@@ -54,8 +54,6 @@
 
 #define COLUMN_HEADER_HEIGHT 16
 
-G_DEFINE_TYPE (ETree, e_tree, GTK_TYPE_TABLE)
-
 #define d(x)
 
 #if d(!)0
@@ -76,6 +74,11 @@ enum {
 	STATE_CHANGE,
 	WHITE_SPACE_EVENT,
 
+	CUT_CLIPBOARD,
+	COPY_CLIPBOARD,
+	PASTE_CLIPBOARD,
+	SELECT_ALL,
+
 	TREE_DRAG_BEGIN,
 	TREE_DRAG_END,
 	TREE_DRAG_DATA_GET,
@@ -245,6 +248,8 @@ static void hover_off (ETree *et);
 static void hover_on (ETree *et, gint x, gint y);
 static void context_destroyed (gpointer data, GObject *ctx);
 
+G_DEFINE_TYPE (ETree, e_tree, GTK_TYPE_TABLE)
+
 static void
 et_disconnect_from_etta (ETree *et)
 {
@@ -501,8 +506,6 @@ et_search_search (ETableSearch *search, gchar *string, ETableSearchFlags flags,
 		e_tree_table_adapter_show_node (et->priv->etta, found);
 		model_row = e_tree_table_adapter_row_of_node (et->priv->etta, found);
 
-		cursor = found;
-
 		e_selection_model_select_as_key_press(E_SELECTION_MODEL (et->priv->selection), model_row, col->col_idx, GDK_CONTROL_MASK);
 		return TRUE;
 	} else if (cursor && !(flags & E_TABLE_SEARCH_FLAGS_CHECK_CURSOR_FIRST)) {
@@ -660,7 +663,7 @@ et_focus (GtkWidget *container, GtkDirectionType direction)
 static void
 set_header_canvas_width (ETree *e_tree)
 {
-	double oldwidth, oldheight, width;
+	gdouble oldwidth, oldheight, width;
 
 	if (!(e_tree->priv->header_item && e_tree->priv->header_canvas && e_tree->priv->table_canvas))
 		return;
@@ -1162,7 +1165,7 @@ e_tree_set_state_object(ETree *e_tree, ETableState *state)
 
 	connect_header (e_tree, state);
 
-	g_value_set_double (val, (double) (GTK_WIDGET(e_tree->priv->table_canvas)->allocation.width));
+	g_value_set_double (val, (gdouble) (GTK_WIDGET(e_tree->priv->table_canvas)->allocation.width));
 	g_object_set_property (G_OBJECT (e_tree->priv->header), "width", val);
 	g_free (val);
 
@@ -2375,10 +2378,10 @@ e_tree_drag_highlight (ETree *tree,
 						       NULL);
 		}
 		gnome_canvas_item_set (tree->priv->drop_highlight,
-				       "x1", (double) x,
-				       "x2", (double) x + width - 1,
-				       "y1", (double) y,
-				       "y2", (double) y + height - 1,
+				       "x1", (gdouble) x,
+				       "x2", (gdouble) x + width - 1,
+				       "y1", (gdouble) y,
+				       "y2", (gdouble) y + height - 1,
 				       NULL);
 	} else {
 		gtk_object_destroy (GTK_OBJECT (tree->priv->drop_highlight));
@@ -2744,7 +2747,7 @@ scroll_timeout (gpointer data)
 	ETree *et = data;
 	gint dx = 0, dy = 0;
 	GtkAdjustment *v, *h;
-	double vvalue, hvalue;
+	gdouble vvalue, hvalue;
 
 	if (et->priv->scroll_direction & ET_SCROLL_DOWN)
 		dy += 20;
@@ -3396,7 +3399,7 @@ e_tree_class_init (ETreeClass *class)
 static void
 tree_size_allocate (GtkWidget *widget, GtkAllocation *alloc, ETree *tree)
 {
-	double width;
+	gdouble width;
 
 	g_return_if_fail (tree != NULL);
 	g_return_if_fail (tree->priv != NULL);
@@ -3441,8 +3444,8 @@ e_tree_set_info_message (ETree *tree, const gchar *info_message)
 						"justification", GTK_JUSTIFY_LEFT,
 						"text", info_message,
 						"draw_background", FALSE,
-						"width", (double) GTK_WIDGET (tree->priv->table_canvas)->allocation.width - 60.0,
-						"clip_width", (double) GTK_WIDGET (tree->priv->table_canvas)->allocation.width - 60.0,
+						"width", (gdouble) GTK_WIDGET (tree->priv->table_canvas)->allocation.width - 60.0,
+						"clip_width", (gdouble) GTK_WIDGET (tree->priv->table_canvas)->allocation.width - 60.0,
 						NULL);
 
 		e_canvas_item_move_absolute (tree->priv->info_text, 30, 30);
